/*
 * Tencent is pleased to support the open source community by making BK-JOB蓝鲸智云作业平台 available.
 *
 * Copyright (C) 2021 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-JOB蓝鲸智云作业平台 is licensed under the MIT License.
 *
 * License for BK-JOB蓝鲸智云作业平台:
 * --------------------------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
 * THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

package com.tencent.bk.job.common.esb.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Getter;
import lombok.Setter;

/**
 * Job ESB API 的通用请求参数
 */
@Setter
@Getter
public class EsbJobReq extends EsbReq {
    /**
     * ESB 请求-默认分页大小
     */
    public static final Integer DEFAULT_PAGE_LENGTH = 20;
    /**
     * ESB 请求-默认的最大分页大小
     */
    public static final Integer DEFAULT_PAGE_LENGTH_LIMIT = 1000;
    /**
     * 分页-起始位置,默认为0
     */
    @JsonProperty("start")
    private Integer start = 0;

    /**
     * 分页-每页大小
     */
    @JsonProperty("length")
    private Integer length;

    /**
     * 调整默认分页参数。
     * 默认分页大小：EsbJobReq.DEFAULT_PAGE_LENGTH；
     * 默认最大分页大小: EsbJobReq.DEFAULT_PAGE_LENGTH_LIMIT
     */
    public void adjustPageParam() {
        if (start == null || start < 0) {
            start = 0;
        }
        if (length == null || length <= 0) {
            length = DEFAULT_PAGE_LENGTH;
        } else if (length > DEFAULT_PAGE_LENGTH_LIMIT) {
            length = DEFAULT_PAGE_LENGTH_LIMIT;
        }
    }

    /**
     * 调整分页参数
     *
     * @param defaultLength 在不指定分页大小的情况下，使用的默认分页大小
     * @param maxLength     最大分页大小
     */
    public void adjustPageParam(Integer defaultLength, Integer maxLength) {
        if (start == null || start < 0) {
            start = 0;
        }
        if (length == null || length <= 0) {
            length = defaultLength;
        } else if (length > maxLength) {
            length = maxLength;
        }
    }
}
